colour.models.dataset.cie_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.cie_rgb Module

## CIE RGB Colourspace

Defines the CIE RGB colourspace:

- `CIE_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://en.wikipedia.org/wiki/CIE_1931_color_space#Construction_of_the_CIE_XYZ_color_space_from_the_Wright.E2.80.93Guild_data (Last accessed 24 February 2014)

`colour.models.dataset.cie_rgb.` `CIE_RGB_PRIMARIES` = array([[ 0.735, 0.265], [ 0.274, 0.717], [ 0.167, 0.009]])

  CIE RGB colourspace primaries.

  CIE_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.cie_rgb.` `CIE_RGB_WHITEPOINT` = (0.3333333333333333, 0.3333333333333333)

  CIE RGB colourspace whitepoint.

  CIE_RGB_WHITEPOINT : tuple

`colour.models.dataset.cie_rgb.` `CIE_RGB_TO_XYZ_MATRIX` = array([[ 2.76883088, 1.75170933, 1.13013505], [ 1. , 4.59060858, 0.06006668], [ 0. , 0.05650675, 5.5941685 ]])

  CIE RGB colourspace to CIE XYZ colourspace matrix.

  CIE_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.cie_rgb.` `XYZ_TO_CIE_RGB_MATRIX` = array([[ 0.41846571, -0.15866078, -0.08283493], [-0.09116896, 0.25243144, 0.01570752], [ 0.0009209 , -0.00254981, 0.17859891]])

  CIE XYZ colourspace to CIE RGB colourspace matrix.

  XYZ_TO_CIE_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.cie_rgb.` `CIE_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to CIE RGB colourspace.

  CIE_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.cie_rgb.` `CIE_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from CIE RGB colourspace to linear.

  CIE_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.cie_rgb.` `CIE_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1d650>

  CIE RGB colourspace.

  CIE_RGB_COLOURSPACE : RGB_Colourspace